@@ -3,13 +3,14 @@
 ## confint.secr.R
 ## last changed 2009 06 11, 2009 07 16 2009 10 20
 ## 2011 01 31
-## 2011 09 28 field argument added to call to secr.lpredictor
+## 2011 09 28 field argument added to call to secr_lpredictor
 ## 2011 09 28 optimizer changed to optim from nlm
 ## 2011 10 21 not for user-defined density
-## 2014-08-22 modified to include smoothsetup argument for secr.lpredictor()
+## 2014-08-22 modified to include smoothsetup argument for secr_lpredictor()
 ## 2014-10-25 updated for NE
 ## could be sped up by adopting Venzon & Moolgavkar algorithm
 ## e.g. in Bhat package
+## 2025-07-18 adjustments for sigmaxy and noneuc
 ###############################################################################
 
 confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
@@ -30,7 +31,8 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
     profileInterval <- function (parm, ...) {
 
         predicted <- function (beta) {
-            temp <- secr.lpredictor (
+            beta <- secr_fullbeta(beta, object$details$fixedbeta)
+            temp <- secr_lpredictor (
                 formula     = object$model[[parm]], 
                 newdata     = newdata,
                 indx        = object$parindx[[parm]], 
@@ -47,39 +49,40 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
 
         profileLL.lagrange <- function (gamma, parm) {
           
-          data <- prepareSessionData(object$capthist, object$mask, object$details$maskusage, 
-                                     object$design, object$design0, object$detectfn, object$groups, 
-                                     object$fixed, object$hcov, object$details)
-          
-          allvars <- unlist(lapply(object$model, all.vars))
-          learnedresponse <- any(.localstuff$learnedresponses %in% allvars) ## || !is.null(dframe)
-          
-          lagrange <- function (beta2, gamma) {
-            ## return quantity to be maximized
-            templl <- generalsecrloglikfn(
-              beta       = beta2,
-              parindx    = object$parindx,
-              link       = object$link,
-              fixed      = object$fixed,
-              designD    = object$designD,    ## D.designmatrix,
-              designNE   = object$designNE,   ## NE.designmatrix,
-              design     = object$design,
-              design0    = object$design0,
-              CL         = object$CL,
-              detectfn   = object$detectfn,
-              learnedresponse = object$learnedresponse,
-              sessionlevels = session(object$capthist),
-              details    = details,
-              data       = data,
-              betaw      = max(max(nchar(object$betanames)),8))
-            templl - gamma * predicted (beta2)
-          }
-          
-          ## maximize for fixed gamma (equivalent to fixed 'parm')
-          lagrange.fit <- optim (par = complete.beta(object), fn = lagrange, gamma = gamma,
+            data <- secr_prepareSessionData(object$capthist, object$mask, object$details$maskusage, 
+                                              object$design, object$design0, object$detectfn, object$groups, 
+                                              object$fixed, object$hcov, object$details)
+            
+            allvars <- unlist(lapply(object$model, all.vars))
+            learnedresponse <- any(.localstuff$learnedresponses %in% allvars) ## || !is.null(dframe)
+            
+            lagrange <- function (beta2, gamma) {
+                ## return quantity to be maximized
+                templl <- secr_generalsecrloglikfn(
+                    beta       = beta2,
+                    parindx    = object$parindx,
+                    link       = object$link,
+                    fixed      = object$fixed,
+                    designD    = object$designD,    ## D.designmatrix,
+                    designNE   = object$designNE,   ## NE.designmatrix,
+                    design     = object$design,
+                    design0    = object$design0,
+                    CL         = object$CL,
+                    detectfn   = object$detectfn,
+                    learnedresponse = object$learnedresponse,
+                    sessionlevels = session(object$capthist),
+                    details    = details,
+                    data       = data,
+                    betaw      = max(max(nchar(object$betanames)),8))
+                templl - gamma * predicted (beta2)
+            }
+            
+            ## maximize for fixed gamma (equivalent to fixed 'parm')
+        beta <- coef(object)$beta  # secr_complete.beta(object)
+          lagrange.fit <- optim (par = beta, fn = lagrange, gamma = gamma,
                                    hessian = FALSE)
             .localstuff$beta <- lagrange.fit$par
-            lp <- -generalsecrloglikfn (
+            lp <- -secr_generalsecrloglikfn (
                 beta       = .localstuff$beta,
                 parindx    = object$parindx,
                 link       = object$link,
@@ -109,13 +112,14 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
             if (is.null(fb)) fb <- rep(NA, np)
             fb[parm] <- x
             details$fixedbeta <- fb
+            start <- secr_complete.beta(object)
             fit <- secr.fit (
                 capthist   = object$capthist, 
                 mask       = object$mask,
                 buffer     = object$buffer, 
                 CL         = object$CL, 
                 detectfn   = object$detectfn,
-                start      = object$fit$par, 
+                start      = start, 
                 binomN     = details$binomN,
                 link       = object$link, 
                 fixed      = object$fixed, 
@@ -235,22 +239,21 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
     #---------------------------------------------------------------------------------------
 
 
-    memo ('Profile likelihood interval(s)...', tracelevel > 0)
-
+    secr_memo ('Profile likelihood interval(s)...', tracelevel > 0)
     if (!inherits(object, 'secr'))
         stop ("requires 'secr' object")
-    if (userD(object))
-        stop ("not implemented for user-defined density function")
+    if (secr_userD(object))
+        stop ("confint not implemented for user-defined density function")
 
     setNumThreads(ncores)
     
     np <- length(object$betanames)  ## number of beta parameters
 
     ## case 1 - real parameter not 1:1 beta so require lagrange
-    ## case 2 - real parameter but model ~1 so 1:1 beta
+    ## case 2 - real parameter but model ~1 so 1:1 beta:real
     ## case 3 - beta parameter
 
-    case <- rep(3, length(parm))
+    case <- rep(3, length(parm)) # default: numeric index of beta paameter
 
     if (is.character(parm)) {
         OK <- (parm %in% object$realnames)
@@ -263,26 +266,27 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
                 case[i] <- 2
         if (any(case==1)) {
             if (is.null(newdata)) {
-                # newdata <- secr.make.newdata (object)[1,, drop = FALSE]  ## default base levels
                 newdata <- makeNewData (object)[1,, drop = FALSE]  ## default base levels
             }
             if (detector(traps(object$capthist)) %in% c('polygon','polygonX',
                    'transect','transectX','signal','unmarked','presence'))
                 logmult <- 0
             else
-                logmult <- logmultinom(object$capthist, group.factor(object$capthist,
+                logmult <- logmultinom(object$capthist, secr_group.factor(object$capthist,
                     object$groups))
-
-            ## reconstruct density design matrix
-            D.modelled <- (!object$CL || object$details$relativeD) && is.null(object$fixed$D)
-            NE.modelled <- is.function(object$details$userdist) && is.null(object$fixed$noneuc)           
-            sessionlevels <- session(object$capthist)
-            grouplevels <- group.levels(object$capthist, object$groups)
-            smoothsetup <- object$smoothsetup
-            # D.designmatrix <- designmatrix (D.modelled, object$mask, object$model$D,
+            
+            ## reconstruct density design matrix; unclear when this is needed
+            # sessionlevels <- session(object$capthist)
+            # grouplevels <- secr_group.levels(object$capthist, object$groups)
+            # smoothsetup <- object$smoothsetup
+            # D.modelled <- (!object$CL || object$details$relativeD) && is.null(object$fixed$D)
+            # NE.modelled <- secr_NEmodelled (object$details, object$fixed,
+            #                                    .localstuff$spatialparameters)
+            # obsolete
+            # D.designmatrix <- secr_designmatrix (D.modelled, object$mask, object$model$D,
             #                                 grouplevels, sessionlevels, object$sessioncov,
             #                                 smoothsetup$D, object$details$contrasts)
-            # NE.designmatrix <- designmatrix (NE.modelled, object$mask, object$model$noneuc,
+            # NE.designmatrix <- secr_designmatrix (NE.modelled, object$mask, object$model$noneuc,
             #                                 grouplevels, sessionlevels, object$sessioncov,
             #                                 smoothsetup$noneuc, object$details$contrasts)        
         }
@@ -303,7 +307,8 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
     }
 
     for (i in 1:length(parm)) {
-        parmn <- ifelse (case[i] == 2, match(parm[i], object$betanames), parm[i])
+        # convert character to numeric index when case = 2
+        parmn <- ifelse (case[i] == 2, object$parindx[[parm[i]]][1], parm[i])
         out[i,] <- profileInterval(parmn)   ## character value if 'real'
         if (case[i] == 2) out[i,] <- untransform(out[i,], object$link[[parm[i]]])
     }
