@@ -47,6 +47,7 @@ noise      <- function (object, ...) UseMethod("noise")
 
 esa        <- function (object, ...) UseMethod("esa")
 derived    <- function (object, ...) UseMethod("derived")
+derivedDcoef <- function (object, ...) UseMethod("derivedDcoef")
 MCgof      <- function (object, ...) UseMethod("MCgof")
 fxi        <- function (object, ...) UseMethod("fxi")
 fxTotal    <- function (object, ...) UseMethod("fxTotal")
@@ -481,7 +482,7 @@ signalmatrix <- function (object, noise = FALSE, recodezero = FALSE,
                prefix=prefix, signalcovariates = signalcovariates, names = names)
     }
     else {
-        object <- check3D(object)
+        object <- secr_check3D(object)
         tmpsignal <- object
         if (dim(tmpsignal)[2]>1)
             warning("using only first occasion")
@@ -677,7 +678,7 @@ detectionindex <- function (object) {
         if (nrow(object) == 0)
            numeric(0)
         else {
-            object <- check3D(object)
+            object <- secr_check3D(object)
             x <- object
             x[] <- 1:length(x)
             x[abs(object)==0] <- 0
@@ -882,12 +883,12 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
             if (is.null(noccasions)) {
                 if (is.null(dim(value)))
                     stop("usage value should be matrix or scalar with noccasions")
-                else if (nrow(value) != ndetector(object))
+                else if (nrow(value) != secr_ndetector(object))
                     stop("mismatch between value and number of detectors")
             }
             else {
                 ## assume value is scalar
-                value <- matrix(value, nrow = ndetector(object), ncol = noccasions)
+                value <- matrix(value, nrow = secr_ndetector(object), ncol = noccasions)
             }
             if (!is.null(markocc(object))) {
                 if (ncol(value) != length(markocc(object)))
@@ -964,7 +965,7 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
             if (length(value)>1) {
                 if (length(dims <- dim(value)) != 2)
                     stop ("require either total count or traps x occasions matrix")
-                if (dims[1] != ndetector(traps(object)))
+                if (dims[1] != secr_ndetector(traps(object)))
                     stop ("Tu not compatible with traps attribute")
                 if (dims[2] != length(markocc))
                     stop ("Tu not compatible with markocc attribute")
@@ -995,7 +996,7 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
             if (length(value)>1) {
                 if (length(dims <- dim(value)) != 2)
                     stop ("require either total count or traps x occasions matrix")
-                if (dims[1] != ndetector(traps(object)))
+                if (dims[1] != secr_ndetector(traps(object)))
                     stop ("Tm not compatible with traps attribute")
                 if (dims[2] != length(markocc))
                     stop ("Tm not compatible with markocc attribute")
@@ -1026,7 +1027,7 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
             if (length(value)>1) {
                 if (length(dims <- dim(value)) != 2)
                     stop ("require either total count or traps x occasions matrix")
-                if (dims[1] != ndetector(traps(object)))
+                if (dims[1] != secr_ndetector(traps(object)))
                     stop ("Tn not compatible with traps attribute")
                 if (dims[2] != length(markocc))
                     stop ("Tn not compatible with markocc attribute")
@@ -1058,7 +1059,7 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
             if (length(value)>1) {
                 if (length(dims <- dim(value)) != 2)
                     stop ("require traps x occasions matrix")
-                if (dims[1] != ndetector(traps(object)))
+                if (dims[1] != secr_ndetector(traps(object)))
                     stop ("nontarget not compatible with traps attribute")
             }
             if (any(value<0))
@@ -1121,7 +1122,7 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
             }
             else if (inherits(object, 'capthist')) {
                 ## capthist object
-                nsessions <- length(unique(primarysessions(intervals(object))))
+                nsessions <- length(unique(secr_primarysessions(intervals(object))))
                 if (nsessions>1) {    # 2019-09-29
                     OK <- sapply(value, function(x) nsessions == length(x))
                     if (any(!OK))
@@ -1170,8 +1171,8 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
 
 'xy<-' <- function (object, value) {
     if (!is.null(value)) {
-        object <- check3D(object)
-        polyoccasions <- expanddet(object) %in% .localstuff$polydetectors
+        object <- secr_check3D(object)
+        polyoccasions <- secr_expanddet(object) %in% .localstuff$polydetectors
         ndetections <- sum(abs(object[,polyoccasions,]))
         if (nrow(value) != ndetections)
             stop ("requires one location per detection")
@@ -1187,8 +1188,8 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
 
 'telemetryxy<-' <- function (object, value) {
     if (!is.null(value)) {
-        object <- check3D(object)
-        telemoccasions <- expanddet(object) %in% 'telemetry'
+        object <- secr_check3D(object)
+        telemoccasions <- secr_expanddet(object) %in% 'telemetry'
         ndetections <- sum(abs(object[,telemoccasions,]))
         if (sum(sapply(value,nrow)) != ndetections)
             stop ("requires one location per detection")
@@ -1699,8 +1700,8 @@ subset.capthist <- function (x, subset=NULL, occasions=NULL, traps=NULL,
            nk <- 1
         }
         else {
-            detector <- expanddet(x)   # vector 2017-01-28
-            nk <- ndetector (trapsx)
+            detector <- secr_expanddet(x)   # vector 2017-01-28
+            nk <- secr_ndetector (trapsx)
         }
         if (is.logical(subset) & (length(subset) != nrow(x)))
             stop ("if 'subset' is logical its length must match number of animals")
@@ -1962,9 +1963,7 @@ subset.capthist <- function (x, subset=NULL, occasions=NULL, traps=NULL,
                          " all intervals set to 1.0")
                 intervals(temp) <- rep(1, ncol(temp)-1)
             }
-            ## bug fixed 2021-04-22
-            # sessions <- unique(primarysessions(intervals(temp))[occasions])
-            sessions <- unique(primarysessions(interv)[occasions])
+            sessions <- unique(secr_primarysessions(interv)[occasions])
             sessionlabels(temp) <- slabels[sessions]
         }
         ################################################
@@ -2342,7 +2341,7 @@ print.secr <- function (x, newdata = NULL, alpha = 0.05, deriv = FALSE, call = T
             ncapt <- sum(abs(x$capthist)>0)
 
         defaultmarkresight <- list(Tu='as.is', Tm='as.is', Tn='ignore')
-        markresightcontrol <- replacedefaults(defaultmarkresight, x$details$markresight)
+        markresightcontrol <- secr_replacedefaults(defaultmarkresight, x$details$markresight)
 
         Tu <- Tu(x$capthist)
         Tm <- Tm(x$capthist)
@@ -2351,7 +2350,7 @@ print.secr <- function (x, newdata = NULL, alpha = 0.05, deriv = FALSE, call = T
         unmarkedocc <- markocc(traps(x$capthist)) == 0
 
         if ('g' %in% x$vars) {
-            Groups  <- table(group.factor(x$capthist, x$groups))
+            Groups  <- table(secr_group.factor(x$capthist, x$groups))
             temp <- paste (names(Groups), Groups, collapse=', ', sep='=')
             temp <- paste('(',temp,')', sep='')
         }
@@ -2402,14 +2401,14 @@ print.secr <- function (x, newdata = NULL, alpha = 0.05, deriv = FALSE, call = T
     ## Model description
 
     ## 2015-03-31
-    Npar <- nparameters(x)   ## see utility.R
+    Npar <- secr_nparameters(x)   ## see utility.R
     AICval <- 2*(x$fit$value + Npar)
     n <- ifelse (ms(x$capthist), sum(sapply(x$capthist, nrow)), nrow(x$capthist))
     AICcval <- ifelse ((n - Npar - 1) > 0,
         2*(x$fit$value + Npar) + 2 * Npar * (Npar+1) / (n - Npar - 1),
         NA)
     cat ('\n')
-    cat ('Model           : ', model.string(x$model, x$details$userDfn), '\n')
+    cat ('Model           : ', secr_model.string(x$model, x$details$userDfn), '\n')
 
     ## 2013-06-08
     if (!is.null(x$hcov))
@@ -2423,8 +2422,8 @@ print.secr <- function (x, newdata = NULL, alpha = 0.05, deriv = FALSE, call = T
             cat ('User distances  :  dynamic (function)\n')
     }
 
-    cat ('Fixed (real)    : ', fixed.string(x$fixed), '\n')
-    cat ('Detection fn    : ', detectionfunctionname(x$detectfn))
+    cat ('Fixed (real)    : ', secr_fixed.string(x$fixed), '\n')
+    cat ('Detection fn    : ', secr_detectionfunctionname(x$detectfn))
     cat ('\n')
     if (!x$CL)
         cat ('Distribution    : ', x$details$distribution, '\n')
@@ -2510,8 +2509,8 @@ vcov.secr <- function (object, realnames = NULL, newdata = NULL, byrow = FALSE,
         ## average real parameters
         ## vcv among multiple rows
         
-        beta <- complete.beta(object)
-        beta.vcv <- complete.beta.vcv(object)
+        beta <- secr_complete.beta(object)
+        beta.vcv <- secr_complete.beta.vcv(object)
         if (is.null(newdata)) {
             newdata <- makeNewData (object)
         }
@@ -2525,7 +2524,7 @@ vcov.secr <- function (object, realnames = NULL, newdata = NULL, byrow = FALSE,
                 reali <- function (beta, rn) {
                     ## real from all beta pars eval at newdata[i,]
                     par.rn <- object$parindx[[rn]]
-                    mat <- general.model.matrix(
+                    mat <- secr_general.model.matrix(
                         object$model[[rn]], 
                         data = newdatai,
                         gamsmth = object$smoothsetup[[rn]],
@@ -2556,7 +2555,7 @@ vcov.secr <- function (object, realnames = NULL, newdata = NULL, byrow = FALSE,
                 if (rn == 'pmix')
                     stop("vcov does not work at present when realname == 'pmix'")
                 par.rn <- object$parindx[[rn]]
-                mat <- general.model.matrix(
+                mat <- secr_general.model.matrix(
                     object$model[[rn]], 
                     data = newdata,
                     gamsmth = object$smoothsetup[[rn]],
@@ -2576,7 +2575,7 @@ vcov.secr <- function (object, realnames = NULL, newdata = NULL, byrow = FALSE,
             names (vcvlist) <- realnames
             return (vcvlist)
         }
-        ## DIFFERENT VARIANCE TO secr.lpredictor for sigma because there use se.Xuntransfom
+        ## DIFFERENT VARIANCE TO secr_lpredictor for sigma because there use se.Xuntransfom
     }
 }
 
