@@ -163,7 +163,7 @@ randomDensity <- function (mask, parm)
     defaultparm <- list(D = NULL, p = 0.5, A = 0.5, directions = 4, 
                         minpatch = 1, plt = FALSE, seed = NULL, 
                         rescale = TRUE)
-    if (is.null(parm$D)) stop ("myRandomHabitat requires D to be specified")
+    if (is.null(parm$D)) stop ("randomDensity requires D to be specified")
     parm     <- replace(defaultparm, names(parm), parm)
     userargs <- c("p", "A", "directions", "minpatch", "plt", "seed")
     tempmask <- do.call(randomHabitat, 
