@@ -1,5 +1,3 @@
-#include <Rcpp.h>
-#include <RcppParallel.h>
 #include "secr.h"
 
 //==============================================================================
