@@ -8,8 +8,8 @@ library(secr)
 Sys.setenv(RCPP_PARALLEL_BACKEND = "tinythread")
 
 test_that("correct chat.nk ovenbird.model.1", {
-    expect_equal(sapply(chat.nk(ovenbird.model.1), '[[', 'chat'), 
-        c(0.8312778, 1.7388806, 1.3127876, 1.2391087, 1.1826071), 
+    expect_warning(chatnk <- sapply(chat.nk(ovenbird.model.1), '[[', 'chat'))
+    expect_equal(chatnk, c(0.8312778, 1.7388806, 1.3127876, 1.2391087, 1.1826071), 
         tolerance = 1e-5, check.attributes = FALSE)
 })
 
